@@ -569,10 +569,13 @@ void print_window(struct Cell_head *window, int print_flag, int flat_flag)
 
 	    G_set_key_value("proj", "ll", out_proj_info);
 
+#if PROJ_VERSION_MAJOR < 6
+	    /* PROJ6+ has its own datum transformation parameters */
 	    if (G_get_datumparams_from_projinfo(in_proj_info, buff, dum) < 0)
 		G_fatal_error(_("WGS84 output not possible as this location does not contain "
 			       "datum transformation parameters. Try running g.setproj."));
 	    else
+#endif
 		G_set_key_value("datum", "wgs84", out_proj_info);
 
 	    G_set_key_value("unit", "degree", out_unit_info);
