@@ -105,9 +105,7 @@ class AboutWindow(wx.Frame):
 
     def _doLayout(self):
         btnSizer = wx.BoxSizer(wx.HORIZONTAL)
-        btnSizer.Add(self.btnClose, proportion=0,
-                     flag=wx.ALL | wx.ALIGN_RIGHT,
-                     border=5)
+        btnSizer.Add(self.btnClose, proportion=0, flag=wx.ALL, border=5)
 
         sizer = wx.BoxSizer(wx.VERTICAL)
         sizer.Add(self.aboutNotebook, proportion=1,
@@ -226,10 +224,7 @@ class AboutWindow(wx.Frame):
 
         infoGridSizer.AddGrowableCol(0)
         infoGridSizer.AddGrowableCol(1)
-        infoSizer.Add(
-            infoGridSizer,
-            proportion=1,
-            flag=wx.EXPAND | wx.ALIGN_CENTER | wx.ALIGN_CENTER_VERTICAL)
+        infoSizer.Add(infoGridSizer, proportion=1, flag=wx.EXPAND)
 
         row += 2
         infoGridSizer.Add(StaticText(parent=infoTxt, id=wx.ID_ANY,
@@ -825,7 +820,7 @@ class HelpPanel(wx.Panel):
                      flag=wx.ALL, border=5)
         btnSizer.Add(wx.Size(1, 1), proportion=1)
         btnSizer.Add(self.btnNext, proportion=0,
-                     flag=wx.ALIGN_RIGHT | wx.ALL, border=5)
+                     flag=wx.ALL, border=5)
 
         sizer.Add(self.content, proportion=1,
                   flag=wx.EXPAND)
