@@ -2003,6 +2003,9 @@ class LayerTree(treemixin.DragAndDrop, CT.CustomTreeCtrl):
             mapName, found = GetLayerNameFromCmd(dcmd)
             mapLayer = self.GetLayerInfo(layer, key='maplayer')
             self.SetItemText(layer, mapName)
+            # calculates all the positions of the visible items
+            # fix length from item to next non-toplevel window position
+            self.CalculatePositions()
 
             if not mapText or not found:
                 propwin.Hide()
@@ -2150,12 +2153,22 @@ class LayerTree(treemixin.DragAndDrop, CT.CustomTreeCtrl):
 
         self.SetLayerInfo(item, key='maplayer', value=maplayer)
 
-        # if digitization tool enabled -> update list of available vector map
-        # layers
+        # if vector digitization tool enabled -> update list of
+        # available vector map layers
         if self.mapdisplay.GetToolbar('vdigit'):
             self.mapdisplay.GetToolbar(
                 'vdigit').UpdateListOfLayers(updateTool=True)
 
+        # if raster digitization tool enabled -> update list of
+        # available raster map layers
+        if self.mapdisplay.GetToolbar('rdigit'):
+            rasters = self.GetMap().GetListOfLayers(
+                ltype='raster', mapset=grass.gisenv()['MAPSET'])
+            self.mapdisplay.GetToolbar(
+                'rdigit').UpdateRasterLayers(rasters)
+            self.mapdisplay.GetToolbar(
+                'rdigit').SelectDefault()
+
         self.Map.SetLayers(self.GetVisibleLayers())
 
         # redraw map if auto-rendering is enabled
