@@ -23,7 +23,6 @@ import grass.script as grass
 from gui_core.mapdisp import DoubleMapFrame
 from gui_core.dialogs import GetImageHandlers
 from mapwin.base import MapWindowProperties
-from core import globalvar
 from core.render import Map
 from mapdisp import statusbar as sb
 from core.debug import Debug
@@ -46,14 +45,7 @@ class SwipeMapFrame(DoubleMapFrame):
         #
         # Add toolbars
         #
-        toolbars = ['swipeMisc', 'swipeMap', 'swipeMain']
-        if sys.platform == 'win32':
-            self.AddToolbar(toolbars.pop(1))
-            toolbars.reverse()
-        else:
-            self.AddToolbar(toolbars.pop(0))
-        for toolb in toolbars:
-            self.AddToolbar(toolb)
+        self.AddToolbars()
         self._giface = giface
         #
         # create widgets
@@ -177,8 +169,7 @@ class SwipeMapFrame(DoubleMapFrame):
 
         # create statusbar and its manager
         statusbar = self.CreateStatusBar(number=4, style=0)
-        if globalvar.wxPython3:
-            statusbar.SetMinHeight(24)
+        statusbar.SetMinHeight(24)
         statusbar.SetStatusWidths([-5, -2, -1, -1])
         self.statusbarManager = sb.SbManager(
             mapframe=self, statusbar=statusbar)
@@ -275,47 +266,45 @@ class SwipeMapFrame(DoubleMapFrame):
         style ^= wx.SP_LIVE_UPDATE
         self.splitter.SetWindowStyle(style)
 
-    def AddToolbar(self, name):
+    def AddToolbars(self):
         """Add defined toolbar to the window
 
         Currently known toolbars are:
          - 'swipeMap'          - basic map toolbar
          - 'swipeMain'         - swipe functionality
+         - 'swipeMisc'         - misc (settings, help)
         """
-        if name == "swipeMap":
-            self.toolbars[name] = SwipeMapToolbar(self, self._toolSwitcher)
-            self._mgr.AddPane(self.toolbars[name],
-                              wx.aui.AuiPaneInfo().
-                              Name(name).Caption(_("Map Toolbar")).
-                              ToolbarPane().Top().
-                              LeftDockable(False).RightDockable(False).
-                              BottomDockable(False).TopDockable(True).
-                              CloseButton(False).Layer(2).Row(1).
-                              BestSize((self.toolbars[name].GetBestSize())))
+        self.toolbars["swipeMap"] = SwipeMapToolbar(self, self._toolSwitcher)
+        self._mgr.AddPane(self.toolbars["swipeMap"],
+                          wx.aui.AuiPaneInfo().
+                          Name("swipeMap").Caption(_("Map Toolbar")).
+                          ToolbarPane().Top().
+                          LeftDockable(False).RightDockable(False).
+                          BottomDockable(False).TopDockable(True).
+                          CloseButton(False).Layer(2).Row(1).Position(1).
+                          BestSize((self.toolbars["swipeMap"].GetBestSize())))
 
-        if name == "swipeMain":
-            self.toolbars[name] = SwipeMainToolbar(self)
+        self.toolbars["swipeMain"] = SwipeMainToolbar(self)
 
-            self._mgr.AddPane(self.toolbars[name],
-                              wx.aui.AuiPaneInfo().
-                              Name(name).Caption(_("Main Toolbar")).
-                              ToolbarPane().Top().
-                              LeftDockable(False).RightDockable(False).
-                              BottomDockable(False).TopDockable(True).
-                              CloseButton(False).Layer(2).Row(1).
-                              BestSize((self.toolbars[name].GetBestSize())))
+        self._mgr.AddPane(self.toolbars["swipeMain"],
+                          wx.aui.AuiPaneInfo().
+                          Name("swipeMain").Caption(_("Main Toolbar")).
+                          ToolbarPane().Top().
+                          LeftDockable(False).RightDockable(False).
+                          BottomDockable(False).TopDockable(True).
+                          CloseButton(False).Layer(2).Row(1).Position(0).
+                          BestSize((self.toolbars["swipeMain"].GetBestSize())))
 
-        if name == "swipeMisc":
-            self.toolbars[name] = SwipeMiscToolbar(self)
+        self.toolbars["swipeMisc"] = SwipeMiscToolbar(self)
 
-            self._mgr.AddPane(self.toolbars[name],
-                              wx.aui.AuiPaneInfo().
-                              Name(name).Caption(_("Misc Toolbar")).
-                              ToolbarPane().Top().
-                              LeftDockable(False).RightDockable(False).
-                              BottomDockable(False).TopDockable(True).
-                              CloseButton(False).Layer(2).Row(1).
-                              BestSize((self.toolbars[name].GetBestSize())))
+        self._mgr.AddPane(self.toolbars["swipeMisc"],
+                          wx.aui.AuiPaneInfo().
+                          Name("swipeMisc").Caption(_("Misc Toolbar")).
+                          ToolbarPane().Top().
+                          LeftDockable(False).RightDockable(False).
+                          BottomDockable(False).TopDockable(True).
+                          CloseButton(False).Layer(2).Row(1).Position(2).
+                          BestSize((self.toolbars["swipeMisc"].GetBestSize())))
 
     def _addPanes(self):
         """Add splitter window and sliders to aui manager"""
@@ -765,7 +754,8 @@ class SwipeMapFrame(DoubleMapFrame):
         self.GetFirstMap().Clean()
         self.GetSecondMap().Clean()
         self._mgr.UnInit()
-        self._inputDialog.UnInit()
+        if self._inputDialog:
+            self._inputDialog.UnInit()
         self.Destroy()
 
 
@@ -790,7 +780,6 @@ class MapSplitter(wx.SplitterWindow):
     def Init(self):
         self.OnSashChanged(evt=None)
         self.SetMinimumPaneSize(0)
-        self.SetSashSize(self.sashWidthMin)
 
     # def OnMotion(self, event):
     #     w = self.GetSashSize()
