@@ -129,8 +129,7 @@ class ImportDialog(wx.Dialog):
         self.Bind(wx.EVT_CLOSE, lambda evt: self.Destroy())
 
         self.notebook = GNotebook(parent=self,
-                                  style=FN.FNB_FANCY_TABS | FN.FNB_BOTTOM |
-                                  FN.FNB_NO_X_BUTTON)
+                                  style=globalvar.FNPageDStyle)
 
         self.notebook.AddPage(page=self.panel,
                               text=_('Source settings'),
@@ -213,7 +212,7 @@ class ImportDialog(wx.Dialog):
         dialogSizer.Add(
             btnsizer,
             proportion=0,
-            flag=wx.ALIGN_CENTER_VERTICAL | wx.BOTTOM | wx.ALIGN_RIGHT,
+            flag=wx.BOTTOM | wx.ALIGN_RIGHT,
             border=10)
 
         # dialogSizer.SetSizeHints(self.panel)
@@ -954,7 +953,7 @@ class ReprojectionDialog(wx.Dialog):
         dialogSizer.Add(
             btnsizer,
             proportion=0,
-            flag=wx.ALIGN_CENTER_VERTICAL | wx.BOTTOM | wx.ALIGN_RIGHT,
+            flag=wx.BOTTOM | wx.ALIGN_RIGHT,
             border=10)
 
         self.panel.SetSizer(dialogSizer)
