@@ -42,7 +42,7 @@ from core.utils import PilImageToWxImage
 from gui_core.forms import GUI
 from gui_core.dialogs import HyperlinkDialog
 from gui_core.ghelp import ShowAboutDialog
-from gui_core.wrap import ClientDC, PseudoDC, Rect, StockCursor, EmptyBitmap, NewId
+from gui_core.wrap import ClientDC, PseudoDC, Rect, StockCursor, EmptyBitmap
 from psmap.menudata import PsMapMenuData
 from gui_core.toolbars import ToolSwitcher
 
@@ -223,14 +223,14 @@ class PsMapFrame(wx.Frame):
         """
         mainSizer = wx.BoxSizer(wx.VERTICAL)
         if globalvar.hasAgw:
-            self.book = fnb.FlatNotebook(parent=self, id=wx.ID_ANY,
-                                         agwStyle=fnb.FNB_FANCY_TABS | fnb.FNB_BOTTOM |
-                                         fnb.FNB_NO_NAV_BUTTONS | fnb.FNB_NO_X_BUTTON)
+            self.book = fnb.FlatNotebook(parent=self,
+                                         id=wx.ID_ANY,
+                                         agwStyle=globalvar.FNPageDStyle)
         else:
-            self.book = fnb.FlatNotebook(parent=self, id=wx.ID_ANY,
-                                         style=fnb.FNB_FANCY_TABS | fnb.FNB_BOTTOM |
-                                         fnb.FNB_NO_NAV_BUTTONS | fnb.FNB_NO_X_BUTTON)
-        #self.book = fnb.FlatNotebook(self, wx.ID_ANY, style = fnb.FNB_BOTTOM)
+            self.book = fnb.FlatNotebook(parent=self,
+                                         id=wx.ID_ANY,
+                                         style=globalvar.FNPageDStyle)
+
         self.book.AddPage(self.canvas, "Draft mode")
         self.book.AddPage(self.previewCanvas, "Preview")
         self.book.SetSelection(0)
@@ -1009,7 +1009,7 @@ class PsMapFrame(wx.Frame):
 
     def DialogDataChanged(self, id):
         ids = id
-        if isinstance(id, int) or isinstance(id, wx.WindowIDRef):
+        if isinstance(id, int):
             ids = [id]
         for id in ids:
             itype = self.instruction[id].type
@@ -2528,6 +2528,8 @@ class PsMapBufferedWindow(wx.Window):
         # Make new off screen bitmap: this bitmap will always have the
         # current drawing in it, so it can be used to save the image
         # to a file, or whatever.
+        width = max(width, 20)
+        height = max(height, 20)
         self._buffer = EmptyBitmap(width, height)
         # re-render image on idle
         self.resize = True
