@@ -378,7 +378,6 @@ int GPJ_init_transform(const struct pj_info *info_in,
     else if (info_out->pj == NULL) {
 	const char *projstr = NULL;
 	char *indef = NULL;
-	PJ *source_crs;
 	
 	/* Even Rouault:
 	 * if info_in->def contains a +towgs84/+nadgrids clause, 
@@ -391,15 +390,21 @@ int GPJ_init_transform(const struct pj_info *info_in,
 	 * and in that case, take the source CRS with proj_get_source_crs(),
 	 * and do the inverse transform on it */
 
-	source_crs = proj_get_source_crs(NULL, info_in->pj);
-	if (source_crs) {
-	    projstr = proj_as_proj_string(NULL, source_crs, PJ_PROJ_5, NULL);
-	    if (projstr)
-		indef = G_store(projstr);
-	    proj_destroy(source_crs);
+	if (proj_get_type(info_in->pj) == PJ_TYPE_BOUND_CRS) {
+	    PJ *source_crs;
+
+	    G_debug(1, "transform to ll equivalent: found bound crs");
+	    source_crs = proj_get_source_crs(NULL, info_in->pj);
+	    if (source_crs) {
+		projstr = proj_as_proj_string(NULL, source_crs, PJ_PROJ_5, NULL);
+		if (projstr)
+		    indef = G_store(projstr);
+		proj_destroy(source_crs);
+	    }
 	}
 	if (indef == NULL)
 	    indef = G_store(info_in->def);
+	G_debug(1, "ll equivalent definition: %s", indef);
 
 	/* what about axis order?
 	 * is it always enu? 
@@ -937,7 +942,7 @@ int GPJ_transform(const struct pj_info *info_in,
 	/* PROJ 6+: conversion to radians is not always needed:
 	 * if proj_angular_input(info_trans->pj, dir) == 1 
 	 * -> convert from degrees to radians */
-	if (out_is_ll && proj_angular_input(info_trans->pj, dir) == 0) {
+	if (out_is_ll && proj_angular_output(info_trans->pj, dir) == 0) {
 	    out_rad2deg = 0;
 	}
 #endif
@@ -948,7 +953,7 @@ int GPJ_transform(const struct pj_info *info_in,
 	    /* PROJ 6+: conversion to radians is not always needed:
 	     * if proj_angular_input(info_trans->pj, dir) == 1 
 	     * -> convert from degrees to radians */
-	    if (in_is_ll && proj_angular_output(info_trans->pj, dir) == 0) {
+	    if (in_is_ll && proj_angular_input(info_trans->pj, dir) == 0) {
 		in_deg2rad = 0;
 	    }
 #endif
@@ -1152,7 +1157,7 @@ int GPJ_transform_array(const struct pj_info *info_in,
 	/* PROJ 6+: conversion to radians is not always needed:
 	 * if proj_angular_input(info_trans->pj, dir) == 1 
 	 * -> convert from degrees to radians */
-	if (out_is_ll && proj_angular_input(info_trans->pj, dir) == 0) {
+	if (out_is_ll && proj_angular_output(info_trans->pj, dir) == 0) {
 	    out_rad2deg = 0;
 	}
 #endif
@@ -1163,7 +1168,7 @@ int GPJ_transform_array(const struct pj_info *info_in,
 	    /* PROJ 6+: conversion to degrees is not always needed:
 	     * if proj_angular_output(info_trans->pj, dir) == 1 
 	     * -> convert from degrees to radians */
-	    if (in_is_ll && proj_angular_output(info_trans->pj, dir) == 0) {
+	    if (in_is_ll && proj_angular_input(info_trans->pj, dir) == 0) {
 		in_deg2rad = 0;
 	    }
 #endif
