@@ -1,15 +1,17 @@
 #include <stdlib.h>
 #include <string.h>
 #include <grass/gis.h>
+#include <grass/raster.h>
 #include <grass/glocale.h>
 #include "format.h"
 #include "local_proto.h"
 
-int poly_to_rast(char *input_file, char *raster_map, char *title, int nrows)
+int poly_to_rast(char *input_file, char *raster_map, char *title, int nrows, int raster_type, int *null)
 {
     double *x, *y;
     int count;
-    long cat;
+    int cat_int;
+    double cat_double;
     int type;
     struct Categories labels;
     FILE *ifd;			/* for input file */
@@ -31,17 +33,15 @@ int poly_to_rast(char *input_file, char *raster_map, char *title, int nrows)
 	exit(EXIT_FAILURE);
     }
 
-    rfd = G_open_cell_new(raster_map);
-    if (rfd < 0)
-	G_fatal_error(_("Can't create raster map <%s>"), raster_map);
+    rfd = Rast_open_new(raster_map, raster_type);
 
     if (title == NULL)
 	title = "";
     G_strip(title);
 
-    G_init_cats((CELL) 0, title, &labels);
+    Rast_init_cats(title, &labels);
 
-    format = getformat(ifd);
+    format = getformat(ifd, raster_type, null);
     
     /* ?? otherwise get complaints about window changes */
     G_suppress_warnings(TRUE);
@@ -55,9 +55,12 @@ int poly_to_rast(char *input_file, char *raster_map, char *title, int nrows)
 	if (npasses > 1)
 	    G_message(_("Pass #%d (of %d) ..."), pass, npasses);
 
-	fseek(ifd, 0L, 0);
-	while (get_item(ifd, &type, &cat, &x, &y, &count, &labels)) {
-	    set_cat(cat);
+	G_fseek(ifd, 0L, 0);
+	while (get_item(ifd, format, &type, &cat_int, &cat_double, &x, &y, &count, &labels)) {
+	    if (format == USE_FCELL || format == USE_DCELL)
+		set_cat_double(cat_double);
+	    else
+		set_cat_int(cat_int);
 	    switch (type) {
 	    case 'A':
 		G_plot_polygon(x, y, count);
@@ -77,7 +80,7 @@ int poly_to_rast(char *input_file, char *raster_map, char *title, int nrows)
 
 	G_message(_("Writing raster map..."));
 
-	stat = output_raster(rfd);
+	stat = output_raster(rfd, null);
     } while (stat == 0);
     /* stat: 0 means repeat
      *       1 means done
@@ -85,15 +88,15 @@ int poly_to_rast(char *input_file, char *raster_map, char *title, int nrows)
      */
 
     if (stat < 0) {
-	G_unopen_cell(rfd);
+	Rast_unopen(rfd);
 	return 1;
     }
 
-    G_close_cell(rfd);
-    G_write_cats(raster_map, &labels);
-    G_short_history(raster_map, "raster", &history);
-    G_command_history(&history);
-    G_write_history(raster_map, &history);
+    Rast_close(rfd);
+    Rast_write_cats(raster_map, &labels);
+    Rast_short_history(raster_map, "raster", &history);
+    Rast_command_history(&history);
+    Rast_write_history(raster_map, &history);
 
     return 0;
 }
